/*****************************************************************************/
/*                                                                           */
/*                                 palette.c                                 */
/*                                                                           */
/*      Color palette definition for the sp65 sprite and bitmap utility      */
/*                                                                           */
/*                                                                           */
/*                                                                           */
/* (C) 2012,      Ullrich von Bassewitz                                      */
/*                Roemerstrasse 52                                           */
/*                D-70794 Filderstadt                                        */
/* EMail:         uz@cc65.org                                                */
/*                                                                           */
/*                                                                           */
/* This software is provided 'as-is', without any expressed or implied       */
/* warranty.  In no event will the authors be held liable for any damages    */
/* arising from the use of this software.                                    */
/*                                                                           */
/* Permission is granted to anyone to use this software for any purpose,     */
/* including commercial applications, and to alter it and redistribute it    */
/* freely, subject to the following restrictions:                            */
/*                                                                           */
/* 1. The origin of this software must not be misrepresented; you must not   */
/*    claim that you wrote the original software. If you use this software   */
/*    in a product, an acknowledgment in the product documentation would be  */
/*    appreciated but is not required.                                       */
/* 2. Altered source versions must be plainly marked as such, and must not   */
/*    be misrepresented as being the original software.                      */
/* 3. This notice may not be removed or altered from any source              */
/*    distribution.                                                          */
/*                                                                           */
/*****************************************************************************/



/* common */
#include "check.h"
#include "xmalloc.h"

/* sp65 */
#include "palette.h"



/*****************************************************************************/
/*                                   Code                                    */
/*****************************************************************************/



Palette* NewPalette (unsigned Entries)
/* Create a new palette with the given number of entries */
{
    Palette* P;

    /* Some safety checks */
    PRECONDITION (Entries > 0 && Entries <= 256);

    /* Allocate memory */
    P = xmalloc (sizeof (*P) + (Entries - 1) * sizeof (P->Entries[0]));

    /* Initialize the struct, then return it */
    P->Count = Entries;
    return P;
}



void FreePalette (Palette* P)
/* Free a dynamically allocated palette */
{
    xfree (P);
}



